diff --git a/jOOQ/src/main/java/org/jooq/Case.java b/jOOQ/src/main/java/org/jooq/Case.java index 2463181749..ce0d7d105f 100644 --- a/jOOQ/src/main/java/org/jooq/Case.java +++ b/jOOQ/src/main/java/org/jooq/Case.java @@ -35,7 +35,7 @@ */ package org.jooq; -import org.jooq.impl.Executor; +import org.jooq.impl.Factory; /** @@ -52,7 +52,7 @@ import org.jooq.impl.Executor; * ELSE 'three' * END * Instances of Case are created through the - * {@link Executor#decode()} method + * {@link Factory#decode()} method * * @author Lukas Eder */ diff --git a/jOOQ/src/main/java/org/jooq/Condition.java b/jOOQ/src/main/java/org/jooq/Condition.java index c98c103c3f..e772519546 100644 --- a/jOOQ/src/main/java/org/jooq/Condition.java +++ b/jOOQ/src/main/java/org/jooq/Condition.java @@ -36,7 +36,8 @@ package org.jooq; -import org.jooq.impl.Executor; +import org.jooq.impl.Factory; + /** * A condition to be used in a query's where part @@ -66,7 +67,7 @@ public interface Condition extends QueryPart { * * @param sql The other condition * @return The combined condition - * @see Executor#condition(String) + * @see Factory#condition(String) */ @Support Condition and(String sql); @@ -83,7 +84,7 @@ public interface Condition extends QueryPart { * @param sql The other condition * @param bindings The bindings * @return The combined condition - * @see Executor#condition(String, Object...) + * @see Factory#condition(String, Object...) */ @Support Condition and(String sql, Object... bindings); @@ -102,7 +103,7 @@ public interface Condition extends QueryPart { * @param parts The {@link QueryPart} objects that are rendered at the * {numbered placeholder} locations * @return The combined condition - * @see Executor#condition(String, QueryPart...) + * @see Factory#condition(String, QueryPart...) */ @Support Condition and(String sql, QueryPart... parts); @@ -158,7 +159,7 @@ public interface Condition extends QueryPart { * * @param sql The other condition * @return The combined condition - * @see Executor#condition(String) + * @see Factory#condition(String) */ @Support Condition or(String sql); @@ -175,7 +176,7 @@ public interface Condition extends QueryPart { * @param sql The other condition * @param bindings The bindings * @return The combined condition - * @see Executor#condition(String, Object...) + * @see Factory#condition(String, Object...) */ @Support Condition or(String sql, Object... bindings); @@ -194,7 +195,7 @@ public interface Condition extends QueryPart { * @param parts The {@link QueryPart} objects that are rendered at the * {numbered placeholder} locations * @return The combined condition - * @see Executor#condition(String, Object...) + * @see Factory#condition(String, Object...) */ @Support Condition or(String sql, QueryPart... parts); @@ -232,7 +233,7 @@ public interface Condition extends QueryPart { /** * Invert this condition *
- * This is the same as calling {@link Executor#not(Condition)}
+ * This is the same as calling {@link Factory#not(Condition)}
*
* @return This condition, inverted
*/
diff --git a/jOOQ/src/main/java/org/jooq/SelectConditionStep.java b/jOOQ/src/main/java/org/jooq/SelectConditionStep.java
index 545db7e112..313e05f8b4 100644
--- a/jOOQ/src/main/java/org/jooq/SelectConditionStep.java
+++ b/jOOQ/src/main/java/org/jooq/SelectConditionStep.java
@@ -35,7 +35,8 @@
*/
package org.jooq;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
+
/**
* This type is used for the {@link Select}'s DSL API when selecting generic
@@ -97,7 +98,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectConditionStep and(String sql);
@@ -111,7 +112,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectConditionStep and(String sql, Object... bindings);
@@ -125,7 +126,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectConditionStep and(String sql, QueryPart... parts);
@@ -167,7 +168,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectConditionStep or(String sql);
@@ -181,7 +182,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectConditionStep or(String sql, Object... bindings);
@@ -195,7 +196,7 @@ public interface SelectConditionStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectConditionStep or(String sql, QueryPart... parts);
diff --git a/jOOQ/src/main/java/org/jooq/SelectHavingConditionStep.java b/jOOQ/src/main/java/org/jooq/SelectHavingConditionStep.java
index f92214200d..1376c512d3 100644
--- a/jOOQ/src/main/java/org/jooq/SelectHavingConditionStep.java
+++ b/jOOQ/src/main/java/org/jooq/SelectHavingConditionStep.java
@@ -35,7 +35,8 @@
*/
package org.jooq;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
+
/**
* This type is used for the {@link Select}'s DSL API when selecting generic
@@ -97,7 +98,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectHavingConditionStep and(String sql);
@@ -111,7 +112,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectHavingConditionStep and(String sql, Object... bindings);
@@ -125,7 +126,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectHavingConditionStep and(String sql, QueryPart... parts);
@@ -167,7 +168,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectHavingConditionStep or(String sql);
@@ -181,7 +182,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectHavingConditionStep or(String sql, Object... bindings);
@@ -195,7 +196,7 @@ public interface SelectHavingConditionStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectHavingConditionStep or(String sql, QueryPart... parts);
diff --git a/jOOQ/src/main/java/org/jooq/SelectHavingStep.java b/jOOQ/src/main/java/org/jooq/SelectHavingStep.java
index c549a14588..cbf281fcd2 100644
--- a/jOOQ/src/main/java/org/jooq/SelectHavingStep.java
+++ b/jOOQ/src/main/java/org/jooq/SelectHavingStep.java
@@ -37,7 +37,7 @@ package org.jooq;
import java.util.Collection;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
/**
* This type is used for the {@link Select}'s DSL API when selecting generic
@@ -103,7 +103,7 @@ public interface SelectHavingStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectHavingConditionStep having(String sql);
@@ -116,7 +116,7 @@ public interface SelectHavingStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectHavingConditionStep having(String sql, Object... bindings);
@@ -129,7 +129,7 @@ public interface SelectHavingStep extends SelectOrderByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectHavingConditionStep having(String sql, QueryPart... parts);
diff --git a/jOOQ/src/main/java/org/jooq/SelectWhereStep.java b/jOOQ/src/main/java/org/jooq/SelectWhereStep.java
index 5c29f54f4d..f67185fa2e 100644
--- a/jOOQ/src/main/java/org/jooq/SelectWhereStep.java
+++ b/jOOQ/src/main/java/org/jooq/SelectWhereStep.java
@@ -37,7 +37,7 @@ package org.jooq;
import java.util.Collection;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
/**
* This type is used for the {@link Select}'s DSL API when selecting generic
@@ -103,7 +103,7 @@ public interface SelectWhereStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
SelectConditionStep where(String sql);
@@ -116,7 +116,7 @@ public interface SelectWhereStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
SelectConditionStep where(String sql, Object... bindings);
@@ -129,7 +129,7 @@ public interface SelectWhereStep extends SelectConnectByStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
SelectConditionStep where(String sql, QueryPart... parts);
diff --git a/jOOQ/src/main/java/org/jooq/UpdateWhereStep.java b/jOOQ/src/main/java/org/jooq/UpdateWhereStep.java
index e81f5dfbef..03a3268ce5 100644
--- a/jOOQ/src/main/java/org/jooq/UpdateWhereStep.java
+++ b/jOOQ/src/main/java/org/jooq/UpdateWhereStep.java
@@ -37,7 +37,7 @@ package org.jooq;
import java.util.Collection;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
/**
* This type is used for the {@link Update}'s DSL API.
@@ -76,7 +76,7 @@ public interface UpdateWhereStepDECODE() function
* DECODE() function
*
diff --git a/jOOQ/src/main/java/org/jooq/DeleteConditionStep.java b/jOOQ/src/main/java/org/jooq/DeleteConditionStep.java
index 41cd4589a1..ee5926a22e 100644
--- a/jOOQ/src/main/java/org/jooq/DeleteConditionStep.java
+++ b/jOOQ/src/main/java/org/jooq/DeleteConditionStep.java
@@ -35,7 +35,8 @@
*/
package org.jooq;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
+
/**
* This type is used for the {@link Delete}'s DSL API.
@@ -68,7 +69,7 @@ public interface DeleteConditionStep
* Bind values created with {@link Executor#val(Object)} will have their bind
* index as name.
*
* @see Param
- * @see Executor#param(String, Object)
+ * @see Factory#param(String, Object)
*/
Map
* Bind values created with {@link Executor#val(Object)} will have their bind
* index as name.
*
* @see Param
- * @see Executor#param(String, Object)
+ * @see Factory#param(String, Object)
*/
Param> getParam(String name);
@@ -68,7 +69,7 @@ public interface DeleteConditionStep
* This type is used for the {@link Delete}'s DSL API.
- * Bind values created with {@link Executor#val(Object)} will have their bind
+ * Bind values created with {@link Factory#val(Object)} will have their bind
* index as name.
*
@@ -68,7 +69,7 @@ public interface DeleteConditionStep
*/
Map
- * Bind values created with {@link Executor#val(Object)} will have their bind
+ * Bind values created with {@link Factory#val(Object)} will have their bind
* index as name.
*
diff --git a/jOOQ/src/main/java/org/jooq/TableOnConditionStep.java b/jOOQ/src/main/java/org/jooq/TableOnConditionStep.java
index a41d9685f6..86a5cce997 100644
--- a/jOOQ/src/main/java/org/jooq/TableOnConditionStep.java
+++ b/jOOQ/src/main/java/org/jooq/TableOnConditionStep.java
@@ -35,7 +35,8 @@
*/
package org.jooq;
-import org.jooq.impl.Executor;
+import org.jooq.impl.Factory;
+
/**
* An intermediate (optional) type for the construction of a
* Don't mix this up with the various {@link Executor#decode()} methods!
*/
public static Field
* Don't mix this up with the various {@link Executor#decode()} methods!
*/
public static FieldJOIN
@@ -63,7 +64,7 @@ public interface TableOnConditionStep extends TableJOIN clause,
@@ -64,7 +64,7 @@ public interface TableOnStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String)
+ * @see Factory#condition(String)
*/
@Support
TableOnConditionStep on(String sql);
@@ -77,7 +77,7 @@ public interface TableOnStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, Object...)
+ * @see Factory#condition(String, Object...)
*/
@Support
TableOnConditionStep on(String sql, Object... bindings);
@@ -90,7 +90,7 @@ public interface TableOnStep {
* malicious SQL injection. Be sure to properly use bind variables and/or
* escape literals when concatenated into SQL clauses!
*
- * @see Executor#condition(String, QueryPart...)
+ * @see Factory#condition(String, QueryPart...)
*/
@Support
TableOnConditionStep on(String sql, QueryPart... parts);
@@ -35,7 +35,8 @@
/**
* An intermediate (optional) type for the construction of a
- * Don't mix this up with the various {@link Executor#decode()} methods!
+ * Don't mix this up with the various {@link Factory#decode()} methods!
*/
public static Field
@@ -35,7 +35,8 @@
*/
public static Field
- * Don't mix this up with the various {@link Executor#decode()} methods!
+ * Don't mix this up with the various {@link Factory#decode()} methods!
*/
public static FieldJOIN